@@ -2,10 +2,10 @@ package Lcom::Index::ChangePassword;
 
 use Pcore -class, -l10n;
 
-with qw[Pcore::App::Controller::Ext];
+with qw[Pcore::App::Controller Pcore::App::Controller::Ext];
 
 has ext_app   => 'ChangePassword';
-has ext_title => l10n('Change Password');
+has ext_title => sub { l10n('Change Password') };
 has path      => '/change-password/', init_arg => undef;
 
 1;
